@@ -1,9 +1,11 @@
 import hashlib
 import json
+import os
+import warnings
 from pathlib import Path
 from typing import Union
 
-from pymbse.query.config.numpy_encoder import NumpyEncoder
+from pymbse.query.config.numpy_encoder import NumpyEncoder  # type: ignore
 
 
 def hash_dict(dict_to_hash: dict) -> str:
@@ -22,5 +24,12 @@ def hash_file(abs_path: Union[Path, str]) -> str:
     :param abs_path: an absolute path to a file
     :return: a string with md5 hash
     """
+    if not os.path.isfile(abs_path):
+        warnings.warn(
+            f"Can't hash an input file {abs_path} as it does not exist. "
+            f"Either create the file or change model_configuration.yml definition."
+        )
+        return hashlib.md5("".encode("utf-8")).hexdigest()
+
     with open(abs_path, "rb") as file:
         return hashlib.md5(file.read()).hexdigest()
